************
Installation
************

pip
===

.. code-block:: bash

   pip install osyris

If you have already installed ``osyris`` in the past, but would like to upgrade, use

.. code-block:: bash

   pip install osyris --upgrade

conda
=====

.. code-block:: bash

   conda install -c conda-forge osyris

From source
===========

.. code-block:: bash

   git clone https://github.com/osyris-project/osyris.git
   cd osyris
   python -m pip install -e .
